<?php
/**
 * This file loads all the options related to Theme Options settings page.
 * 
 * @package Cognize
 * @subpackage Core-Options
 * @category Options
 * @since Cognize 1.0 
 */

/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */

function mudthemes_optionsframework_option_name() {

	// This gets the theme name from the stylesheet
	$themename = wp_get_theme();
	$themename = preg_replace("/\W/", "_", strtolower($themename) );
        
	$optionsframework_settings = get_option( 'optionsframework' );
	$optionsframework_settings['id'] = $themename;
	update_option( 'optionsframework', $optionsframework_settings );
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'options_framework_theme'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
 */

function mudthemes_optionsframework_options() {

        $icons = array('glass', 'music', 'search', 'envelope-o', 'heart', 'star', 'star-o', 'user', 'film', 'th-large', 'th', 'th-list', 'check', 'times', 'search-plus', 'search-minus', 'power-off', 'signal', 'gear', 'cog', 'trash-o', 'home', 'file-o', 'clock-o', 'road', 'download', 'arrow-circle-o-down', 'arrow-circle-o-up', 'inbox', 'play-circle-o', 'rotate-right', 'repeat', 'refresh', 'list-alt', 'lock', 'flag', 'headphones', 'volume-off', 'volume-down', 'volume-up', 'qrcode', 'barcode', 'tag', 'tags', 'book', 'bookmark', 'print', 'camera', 'font', 'bold', 'italic', 'text-height', 'text-width', 'align-left', 'align-center', 'align-right', 'align-justify', 'list', 'dedent', 'outdent', 'indent', 'video-camera', 'photo', 'image', 'picture-o', 'pencil', 'map-marker', 'adjust', 'tint', 'edit', 'pencil-square-o', 'share-square-o', 'check-square-o', 'arrows', 'step-backward', 'fast-backward', 'backward', 'play', 'pause', 'stop', 'forward', 'fast-forward', 'step-forward', 'eject', 'chevron-left', 'chevron-right', 'plus-circle', 'minus-circle', 'times-circle', 'check-circle', 'question-circle', 'info-circle', 'crosshairs', 'times-circle-o', 'check-circle-o', 'ban', 'arrow-left', 'arrow-right', 'arrow-up', 'arrow-down', 'mail-forward', 'share', 'expand', 'compress', 'plus', 'minus', 'asterisk', 'exclamation-circle', 'gift', 'leaf', 'fire', 'eye', 'eye-slash', 'warning', 'exclamation-triangle', 'plane', 'calendar', 'random', 'comment', 'magnet', 'chevron-up', 'chevron-down', 'retweet', 'shopping-cart', 'folder', 'folder-open', 'arrows-v', 'arrows-h', 'bar-chart-o', 'twitter-square', 'facebook-square', 'camera-retro', 'key', 'gears', 'cogs', 'comments', 'thumbs-o-up', 'thumbs-o-down', 'star-half', 'heart-o', 'sign-out', 'linkedin-square', 'thumb-tack', 'external-link', 'sign-in', 'trophy', 'github-square', 'upload', 'lemon-o', 'phone', 'square-o', 'bookmark-o', 'phone-square', 'twitter', 'facebook', 'github', 'unlock', 'credit-card', 'rss', 'hdd-o', 'bullhorn', 'bell', 'certificate', 'hand-o-right', 'hand-o-left', 'hand-o-up', 'hand-o-down', 'arrow-circle-left', 'arrow-circle-right', 'arrow-circle-up', 'arrow-circle-down', 'globe', 'wrench', 'tasks', 'filter', 'briefcase', 'arrows-alt', 'group', 'users', 'chain', 'link', 'cloud', 'flask', 'cut', 'scissors', 'copy', 'files-o', 'paperclip', 'save', 'floppy-o', 'square', 'navicon', 'reorder', 'bars', 'list-ul', 'list-ol', 'strikethrough', 'underline', 'table', 'magic', 'truck', 'pinterest', 'pinterest-square', 'google-plus-square', 'google-plus', 'money', 'caret-down', 'caret-up', 'caret-left', 'caret-right', 'columns', 'unsorted', 'sort', 'sort-down', 'sort-desc', 'sort-up', 'sort-asc', 'envelope', 'linkedin', 'rotate-left', 'undo', 'legal', 'gavel', 'dashboard', 'tachometer', 'comment-o', 'comments-o', 'flash', 'bolt', 'sitemap', 'umbrella', 'paste', 'clipboard', 'lightbulb-o', 'exchange', 'cloud-download', 'cloud-upload', 'user-md', 'stethoscope', 'suitcase', 'bell-o', 'coffee', 'cutlery', 'file-text-o', 'building-o', 'hospital-o', 'ambulance', 'medkit', 'fighter-jet', 'beer', 'h-square', 'plus-square', 'angle-double-left', 'angle-double-right', 'angle-double-up', 'angle-double-down', 'angle-left', 'angle-right', 'angle-up', 'angle-down', 'desktop', 'laptop', 'tablet', 'mobile-phone', 'mobile', 'circle-o', 'quote-left', 'quote-right', 'spinner', 'circle', 'mail-reply', 'reply', 'github-alt', 'folder-o', 'folder-open-o', 'smile-o', 'frown-o', 'meh-o', 'gamepad', 'keyboard-o', 'flag-o', 'flag-checkered', 'terminal', 'code', 'mail-reply-all', 'reply-all', 'star-half-empty', 'star-half-full', 'star-half-o', 'location-arrow', 'crop', 'code-fork', 'unlink', 'chain-broken', 'question', 'info', 'exclamation', 'superscript', 'subscript', 'eraser', 'puzzle-piece', 'microphone', 'microphone-slash', 'shield', 'calendar-o', 'fire-extinguisher', 'rocket', 'maxcdn', 'chevron-circle-left', 'chevron-circle-right', 'chevron-circle-up', 'chevron-circle-down', 'html5', 'css3', 'anchor', 'unlock-alt', 'bullseye', 'ellipsis-h', 'ellipsis-v', 'rss-square', 'play-circle', 'ticket', 'minus-square', 'minus-square-o', 'level-up', 'level-down', 'check-square', 'pencil-square', 'external-link-square', 'share-square', 'compass', 'toggle-down', 'caret-square-o-down', 'toggle-up', 'caret-square-o-up', 'toggle-right', 'caret-square-o-right', 'euro', 'eur', 'gbp', 'dollar', 'usd', 'rupee', 'inr', 'cny', 'rmb', 'yen', 'jpy', 'ruble', 'rouble', 'rub', 'won', 'krw', 'bitcoin', 'btc', 'file', 'file-text', 'sort-alpha-asc', 'sort-alpha-desc', 'sort-amount-asc', 'sort-amount-desc', 'sort-numeric-asc', 'sort-numeric-desc', 'thumbs-up', 'thumbs-down', 'youtube-square', 'youtube', 'xing', 'xing-square', 'youtube-play', 'dropbox', 'stack-overflow', 'instagram', 'flickr', 'adn', 'bitbucket', 'bitbucket-square', 'tumblr', 'tumblr-square', 'long-arrow-down', 'long-arrow-up', 'long-arrow-left', 'long-arrow-right', 'apple', 'windows', 'android', 'linux', 'dribbble', 'skype', 'foursquare', 'trello', 'female', 'male', 'gittip', 'sun-o', 'moon-o', 'archive', 'bug', 'vk', 'weibo', 'renren', 'pagelines', 'stack-exchange', 'arrow-circle-o-right', 'arrow-circle-o-left', 'toggle-left', 'caret-square-o-left', 'dot-circle-o', 'wheelchair', 'vimeo-square', 'turkish-lira', 'try', 'plus-square-o', 'space-shuttle', 'slack', 'envelope-square', 'wordpress', 'openid', 'institution', 'bank', 'university', 'mortar-board', 'graduation-cap', 'yahoo', 'google', 'reddit', 'reddit-square', 'stumbleupon-circle', 'stumbleupon', 'delicious', 'digg', 'pied-piper-square', 'pied-piper', 'pied-piper-alt', 'drupal', 'joomla', 'language', 'fax', 'building', 'child', 'paw', 'spoon', 'cube', 'cubes', 'behance', 'behance-square', 'steam', 'steam-square', 'recycle', 'automobile', 'car', 'cab', 'taxi', 'tree', 'spotify', 'deviantart', 'soundcloud', 'database', 'file-pdf-o', 'file-word-o', 'file-excel-o', 'file-powerpoint-o', 'file-photo-o', 'file-picture-o', 'file-image-o', 'file-zip-o', 'file-archive-o', 'file-sound-o', 'file-audio-o', 'file-movie-o', 'file-video-o', 'file-code-o', 'vine', 'codepen', 'jsfiddle', 'life-bouy', 'life-saver', 'support', 'life-ring', 'circle-o-notch', 'ra', 'rebel', 'ge', 'empire', 'git-square', 'git', 'hacker-news', 'tencent-weibo', 'qq', 'wechat', 'weixin', 'send', 'paper-plane', 'send-o', 'paper-plane-o', 'history', 'circle-thin', 'header', 'paragraph', 'sliders', 'share-alt', 'share-alt-square', 'bomb');
	$options = array();
        
        $options[] = array(
            'name' => __('Basic Settings', 'cognize'),
            'type' => 'heading');
        
        $options[] = array(
            'name' => __('Select Skin', 'cognize'),
            'desc' => __('More Skins are available only in the <a href="'.COGNIZE_PRO_URL.'" title="Get Cognize PRO">Cognize Pro</a> version.', 'cognize'),
            'id' => 'skin',
            'std' => 'white',
            'type' => 'select',
            'options' => array(
                'white' => __('Classic White', 'cognize'))
        );

        $options[] = array(
            'name' => __('Logo Image:', 'cognize'),
            'desc' => __('The logo image will replace site title.', 'cognize'),
            'std' => '',
            'id' => 'logo_img',
            'type' => 'upload');
        
        $options[] = array(
            'name' => __('Company Name:', 'cognize'),
            'desc' => __('This will be shown in the Theme\'s footer.', 'cognize'),
            'id' => 'footer_name',
            'std' => '',
            'type' => 'text');
        
        $options[] = array(
            'name' => __('Hide Site Description:', 'cognize'),
            'desc' => __('Checking this will hide site description from the header.', 'cognize'),
            'id' => 'disable_site_desc',
            'std' => '1',
            'type' => 'checkbox');
        
        $options[] = array(
            'name' => __('Hide Menu:', 'cognize'),
            'desc' => __('Checking this will hide Primary Menu.', 'cognize'),
            'id' => 'disable_menu',
            'std' => '0',
            'type' => 'checkbox');
        
        $options[] = array(
            'name' => __('Show Copyright:', 'cognize'),
            'desc' => __('Check this setting to show the Copyright information in the Theme\'s footer', 'cognize'),
            'id' => 'show_copyright',
            'std' => '1',
            'type' => 'checkbox');
        
        /* CTA (starts) */

        $options[] = array(
            'name' => __('Featured Section', 'cognize'),
            'type' => 'heading');

        $options[] = array(
            'name' => __('Hide Featured Section:', 'cognize'),
            'desc' => __('Checking this will hide Featured Section.', 'cognize'),
            'id' => 'disable_cta_section',
            'std' => '1',
            'type' => 'checkbox');
        
        $options[] = array(
            'name' => __('Hide Icons:', 'cognize'),
            'desc' => __('Checking this will hide icons from the buttons.', 'cognize'),
            'id' => 'disable_cta_icons',
            'std' => '0',
            'type' => 'checkbox');
        
        $options[] = array(
            'name' => __('Featured Image:', 'cognize'),
            'desc' => '',
            'std' => COGNIZE_GLOBAL_IMAGES_URL . 'horse.jpg',
            'id' => 'featured_image',
            'type' => 'upload');

        $options[] = array(
            'name' => __('Featured Heading:', 'cognize'),
            'desc' => __('Enter featured heading text', 'cognize'),
            'id' => 'featured_heading',
            'std' => 'Headlines Text !',
            'type' => 'textarea');

        $options[] = array(
            'name' => __('Featured Content:', 'cognize'),
            'desc' => __('Enter featured content text', 'cognize'),
            'id' => 'featured_content',
            'std' => 'This is the featured section of Cognize Theme. In order to change this text. Go to Theme Options (Featured Section). If you are unable to do so then please see the theme documentation or contact support.',
            'type' => 'textarea');

        $options[] = array(
            'name' => __('CTA Button #1', 'cognize'),
            'desc' => __('Enter the tittle of first CTA Button', 'cognize'),
            'id' => 'cta_button_1',
            'std' => 'Button #1',
            'type' => 'textarea');

        $options[] = array(
            'name' => __('CTA Button #1 (URL)', 'cognize'),
            'desc' => __('Enter the URL of first CTA Button', 'cognize'),
            'id' => 'cta_button_url_1',
            'std' => 'http://www.mudthemes.com',
            'type' => 'textarea');

        $options[] = array(
            'name' => __('CTA Button #1 Icon:', 'cognize'),
            'desc' => __('Select the icon of first CTA Button.', 'cognize'),
            'id' => 'cta_button_icon_1',
            'std' => 'check',
            'type' => 'radioicons',
            'options' => $icons);
        
        $options[] = array(
            'name' => __('CTA Button #2', 'cognize'),
            'desc' => __('Enter the tittle of second CTA Button', 'cognize'),
            'id' => 'cta_button_2',
            'std' => 'Button #2',
            'type' => 'textarea');

        $options[] = array(
            'name' => __('CTA Button #2 (URL)', 'cognize'),
            'desc' => __('Enter the URL of second CTA Button', 'cognize'),
            'id' => 'cta_button_url_2',
            'std' => 'http://www.mudthemes.com',
            'type' => 'textarea');
        
        $options[] = array(
            'name' => __('CTA Button #2 Icon:', 'cognize'),
            'desc' => __('Select the icon of Second CTA Button.', 'cognize'),
            'id' => 'cta_button_icon_2',
            'std' => 'download',
            'type' => 'radioicons',
            'options' => $icons);
        
        /*3 Content Boxes (starts)*/

        $options[] = array(
            'name' => __('3 Content Boxes', 'cognize'),
            'type' => 'heading');

        $options[] = array(
            'name' => __('Hide Content Boxes:', 'cognize'),
            'desc' => __('Checking this will hide the \'3 content boxes\' throughout the website. (This is a global setting and will override others)', 'cognize'),
            'id' => 'disable_featured_boxes',
            'std' => '1',
            'type' => 'checkbox');

        $options[] = array(
            'name' => __('Content Box #1 (Title):', 'cognize'),
            'desc' => __('This will be the title of the 1st content box.', 'cognize'),
            'id' => 'featured_box_1_title',
            'std' => 'Responsive Design',
            'type' => 'text');

        $options[] = array(
            'name' => __('Content Box #1 (Content):', 'cognize'),
            'desc' => __('This will be the content of the 1st content box.', 'cognize'),
            'id' => 'featured_box_1_content',
            'std' => 'Lorem ipsum dolor sit amet, ea graece laoreet deseruisse cum, sea id erat dicant adolescens nullam.',
            'type' => 'textarea');

        $options[] = array(
            'name' => __('Content Box #1 (Icon):', 'cognize'),
            'desc' => __('This will be the icon of the 1st content box.', 'cognize'),
            'id' => 'featured_box_1_icon',
            'std' => 'desktop',
            'type' => 'radioicons',
            'options' => $icons);

        $options[] = array(
            'name' => __('Content Box #2 (Title):', 'cognize'),
            'desc' => __('This will be the title of the 2nd content box.', 'cognize'),
            'id' => 'featured_box_2_title',
            'std' => 'Full width Layout',
            'type' => 'text');

        $options[] = array(
            'name' => __('Content Box #2 (Content):', 'cognize'),
            'desc' => __('This will be the Content of the 2nd content box.', 'cognize'),
            'id' => 'featured_box_2_content',
            'std' => 'Has errem viris et, ne mel agam eros labore. In ius errem nullam, per et soluta mollis purto wisi nobis.',
            'type' => 'textarea');

        $options[] = array(
            'name' => __('Content Box #2 (Icon):', 'cognize'),
            'desc' => __('This will be the icon of the 2nd content box.', 'cognize'),
            'id' => 'featured_box_2_icon',
            'std' => 'arrows-h',
            'type' => 'radioicons',
            'options' => $icons);

        $options[] = array(
            'name' => __('Content Box #3 (Title):', 'cognize'),
            'desc' => __('This will be the title of the 3rd content box.', 'cognize'),
            'id' => 'featured_box_3_title',
            'std' => '500+ Google Fonts',
            'type' => 'text');

        $options[] = array(
            'name' => __('Content Box #3 (Content):', 'cognize'),
            'desc' => __('This will be the content of the 3rd content box.', 'cognize'),
            'id' => 'featured_box_3_content',
            'std' => 'Periculis referrentur pro in. Facete doctus postulant ei mei, nec idque graeco ad eam eu utinam.',
            'type' => 'textarea');

        $options[] = array(
            'name' => __('Content Box #3 (Icon):', 'cognize'),
            'desc' => __('This will be the icon of the 3rd content box.', 'cognize'),
            'id' => 'featured_box_3_icon',
            'std' => 'font',
            'type' => 'radioicons',
            'options' => $icons);


        /*3 Content Boxes (ends)*/
               
        /*Social Options (starts)*/
        $options[] = array(
            'name' => __('Social Options', 'cognize'),
            'type' => 'heading');
        
        $options[] = array(
            'name' => __('Hide Social Section:', 'cognize'),
            'desc' => __('Checking this will hide Social Section.', 'cognize'),
            'id' => 'disable_social_section',
            'std' => '0',
            'type' => 'checkbox');
        
        $options[] = array(
            'name' => __('Facebook Profile:', 'cognize'),
            'desc' => __('Include http:// or https:// with the URL.', 'cognize'),
            'id' => 'facebook',
            'std' => '',
            'type' => 'text');
        
        $options[] = array(
            'name' => __('Twitter Profile:', 'cognize'),
            'desc' => __('Include http:// or https:// with the URL.', 'cognize'),
            'id' => 'twitter',
            'std' => '',
            'type' => 'text');
        
        $options[] = array(
            'name' => __('RSS Feed:', 'cognize'),
            'desc' => __('Include http:// or https:// with the URL.', 'cognize'),
            'id' => 'rss',
            'std' => get_bloginfo('rss2_url'),
            'type' => 'text');
        
        $options[] = array(
            'id' => 'mud_social_upgrade',
            'type' => 'social_upgrade');

        /*Social Options (ends)*/

        /*Custom CSS (starts)*/
        $options[] = array(
            'name' => __('Custom CSS', 'cognize'),
            'type' => 'heading');

        $options[] = array(
            'id' => "mudcss_section",
            'type' => 'divstart');

        $options[] = array(
            'name' => __('Custom CSS Styles:', 'cognize'),
            'desc' => __('<strong>Important:</strong> Use this section only if you are well versed with CSS styling. Any bad input here can ruin the entire look of your theme. You can put your custom CSS styles here. It is recommended that you use this section rather than editing <i>style.css</i> directly.', 'cognize'),
            'id' => 'custom_css',
            'std' => '',
            'type' => 'textarea');

        $options[] = array(
            'id' => "mudcss_section",
            'type' => 'divend');
        
        /*Custom CSS (ends)*/
        
	return $options;
}

/*
 * This is an example of how to add custom scripts to the options panel.
 * This example shows/hides an option when a checkbox is clicked.
 */

add_action('mudthemes_optionsframework_custom_scripts', 'mudthemes_optionsframework_custom_scripts');

function mudthemes_optionsframework_custom_scripts() { ?>

<script type="text/javascript">
jQuery(document).ready(function($) {

	$('#example_showhidden').click(function() {
  		$('#section-example_text_hidden').fadeToggle(400);
	});

	if ($('#example_showhidden:checked').val() !== undefined) {
		$('#section-example_text_hidden').show();
	}

});
</script>

<?php
}